@@ -108,13 +108,13 @@ def get_editable_root() -> tuple[Path, Path] | None:
     """
     if (
         not is_editable_install()
-        or r"/build/sagemath/src/sage" == ""
-        or r"/build/sagemath/src/sage/.mesonpy-xo20iew2" == ""
+        or r"/startdir/src/sage" == ""
+        or r"/startdir/src/sage/.mesonpy-6ha3i798" == ""
     ):
         return None
 
-    src = Path(r"/build/sagemath/src/sage").resolve()
-    build = Path(r"/build/sagemath/src/sage/.mesonpy-xo20iew2").resolve()
+    src = Path(r"/startdir/src/sage").resolve()
+    build = Path(r"/startdir/src/sage/.mesonpy-6ha3i798").resolve()
     if src.is_dir() and build.is_dir():
         return src, build
     return None
